@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert to and from Baha'i dates
 
-our $VERSION = '0.2000';
+our $VERSION = '0.2001';
 
 
 use strict;
@@ -466,7 +466,7 @@ Date::Baha::i - Convert to and from Baha'i dates
 
 =head1 VERSION
 
-version 0.2000
+version 0.2001
 
 =head1 SYNOPSIS
 
@@ -492,7 +492,7 @@ version 0.2000
       day   => $day,
   );
 
-  my($bahai_year, $bahai_month, $bahai_day) = ('...', '...', '...');
+  my($bahai_year, $bahai_month, $bahai_day) = (175, 11, 6);
 
   my $date = from_bahai(
       year  => $bahai_year,
@@ -583,6 +583,7 @@ Intercalary Days: Four (or five) days in a leap year, before the last month.
 =head2 DAY NAMES
 
 The days of the Baha'i week are:
+
   1. Jalal    - Glory (Saturday)
   2. Jamal    - Beauty (Sunday)
   3. Kaml     - Perfection (Monday)
@@ -627,10 +628,6 @@ since the Baha'i day begins at sunset.
 
 * The Fast - 2-20 March in the month 'Ala - 19 days from sunrise to sunset
 
-=head1 NAME
-
-Date::Baha::i - Convert to and from Baha'i dates
-
 =head1 FUNCTIONS
 
 =head2 to_bahai()
@@ -807,13 +804,13 @@ Dates are given in common, standard (non-Baha'i) format.
 
 L<Date::Calc>
 
+L<Exporter>
+
 L<Lingua::EN::Numbers>
 
 L<Lingua::EN::Numbers::Years>
 
-L<http://www.projectpluto.com/calendar.htm#bahai>
-
-L<http://www.moonwise.co.uk/year/160bahai.htm>
+L<http://calendar.bahaiq.com/>
 
 =head1 TO DO
 
